doVariableSelection: Remove genes with low variation.

View source: R/CALCPHENOTYPE.R

doVariableSelectionR Documentation

Remove genes with low variation.

Description

This function performs variable selection by removing genes with the lowest variance in the datasets.

Usage

doVariableSelection(exprMat, removeLowVaryingGenes = 0.2)

Arguments

exprMat

A matrix of gene expression levels. rownames() are genes, and colnames() are samples.

removeLowVaryingGenes

The proportion of low varying genes to be removed.The default is .2

Value

A vector of row/genes to keep.

Examples

exprMat <- matrix(seq_len(20), nrow=5,
                  dimnames=list(paste0("gene", 1:5), paste0("sample", 1:4)))
doVariableSelection(exprMat, removeLowVaryingGenes=0.2)

oncoPredict documentation built on June 29, 2026, 5:07 p.m.