View source: R/CALCPHENOTYPE.R
| summarizeGenesByMean | R Documentation |
This function takes a gene expression matrix and if duplicate genes are measured, summarizes them by their means.
summarizeGenesByMean(exprMat)
exprMat |
A gene expression matrix with genes as rownames() and samples as colnames(). |
A gene expression matrix that does not contain duplicate genes.
exprMat <- matrix(seq_len(12), nrow=3,
dimnames=list(paste0("gene", 1:3), paste0("sample", 1:4)))
summarizeGenesByMean(exprMat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.