View source: R/CALCPHENOTYPE.R
| doVariableSelection | R Documentation |
This function performs variable selection by removing genes with the lowest variance in the datasets.
doVariableSelection(exprMat, removeLowVaryingGenes = 0.2)
exprMat |
A matrix of gene expression levels. rownames() are genes, and colnames() are samples. |
removeLowVaryingGenes |
The proportion of low varying genes to be removed.The default is .2 |
A vector of row/genes to keep.
exprMat <- matrix(seq_len(20), nrow=5,
dimnames=list(paste0("gene", 1:5), paste0("sample", 1:4)))
doVariableSelection(exprMat, removeLowVaryingGenes=0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.